# send2slack

`send2slack` is a command line tool used in the tutoring activities of the Fondamenti di Informatica course at UniPV.

## Getting Started

These instructions will describe how to setup `send2slack` and `slack_init` (the tool used to configure `send2slack`) and get them up an running on the workspace used by students and tutors.

### Prerequisites

First of all, you need to [create a new Slack App](https://api.slack.com/apps) in the workspace as a new user (*FdI File Manager*). This user will post the files upon student request, and you can customize its profile photo and display name as you wish.

Once created, you need to get a new Slack **API User token** for the user *FdI File Manager*, that will look like this:

    xoxp-000000000000-0000000000000-0000000000000-00000000000000000000000000000000

This will be the token used for the authentication process as the user *FdI File Manager*.

Now you have to [enable the following scopes](https://api.slack.com/scopes) associated with the **API User token** you just created:

    channels:history
    channels:read
    channels:write
    chat:write:bot
    chat:write:user
    files:read
    files:write
    files:write:user
    groups:history
    groups:read
    groups:write
    identity.basic
    identity.email
    identity.team
    im:history
    im:read
    im:write
    links:read
    links:write
    mpim:history
    mpim:read
    mpim:write
    remote_files:read
    remote_files:share
    remote_files:write
    search:read
    team:read
    users.profile:read
    users.profile:write
    users:read
    users:read.email
    users:write


You will also need your **workspace ID**. You can find it in any Slack URL as follows:

    https://app.slack.com/client/<workspace_id_here>/...

### Installing

The first thing to do is to install the Slack library for Python 3:

```bash
pip3 install slackclient
```

Now you can copy the two following files contained in this repository in the workspace image, in the `/usr/bin/` folder or similar (you also need to set the execution permissions for both of them, so that students will be able to run the scripts):

    slack_init
    send2slack

The last thing to do is to insert the **API User token** and the **workspace ID** in the configuration section at the beginning of the source of slack_init:

```python
config = { # global configuration
    'slack_token': 'xoxp-000000000000-0000000000000-0000000000000-00000000000000000000000000000000', # Slack API token
    'workspace_id': 'XXXXXXXXX' # Slack workspace id
}
```

## Usage

You can find basic usage instructions for both commands in their help sections:

```bash
slack_init --help
send2slack --help
```

## Built With

* [slackclient](https://github.com/slackapi/python-slackclient) - The Python library that provides an easy access to the Slack API
